/******************** BUTTON.H ********************
 A class for buttons
 Created by: Michael J. Campbell, 5/22/94
 Last Revised: 8/29/94

***************************************************

 Syntax:

 button(A,B,C,D,E,F,G,H,I,J,K)
	A = left x coordinate of button
	B = top y coordinate of button
	C = right x coordinate of button
	D = bottom y coordinate of button
	E = color of button
	F = thickness of button highlight (0,1,2,3)
	G = draw rectangle around button (0,1)
	H = type of font for button label
	I = size of font for button label
	J = write label plain or recessed (0,1)
	K = label (max 25 characters)

***************************************************/

#include <graphics.h>
#include <string.h>
#include <dos.h>
#pragma warn -inl

class button
	{

	public:
		int Xleft;
		int Ytop;
		int Xright;
		int Ybottom;
		int COLOR;
		int HIGHLIGHT;
		int SHADOW;
		int TEMPCOLOR;
		int tempstatus;
		int size;
		int font;
		int fontsize;
		char LABEL[25];
		char onoffstatus[4];
		int outline;
		int etch;

	public:
		button() {};

		button(int left, int top, int right, int bottom, int basecolor,
				 int linesize, int buttonoutline, int labelfont,
				 int textsize,int inset, char label[25])
			{
			Xleft = left;
			Ytop = top;
			Xright = right;
			Ybottom = bottom;
			COLOR = basecolor;
			if(linesize > 3) linesize = 3;
			if(linesize < 0) linesize = 0;
			size = linesize;
			outline = buttonoutline;
			strcpy(LABEL,"");
			strcpy(LABEL,label);
			strcpy(onoffstatus,"ON");
			font = labelfont;
			fontsize = textsize;
			tempstatus = 1;
			etch = inset;

			// Set up button color scheme
			if(COLOR == BLACK) { HIGHLIGHT = WHITE; SHADOW = DARKGRAY; }
			if(COLOR == BLUE) { HIGHLIGHT = LIGHTBLUE; SHADOW = DARKGRAY;}
			if(COLOR == GREEN) { HIGHLIGHT = LIGHTGREEN; SHADOW = DARKGRAY;}
			if(COLOR == CYAN) { HIGHLIGHT = LIGHTCYAN; SHADOW = DARKGRAY;}
			if(COLOR == RED) { HIGHLIGHT = LIGHTRED; SHADOW = DARKGRAY;}
			if(COLOR == BROWN) { HIGHLIGHT = YELLOW; SHADOW = DARKGRAY;}
			if(COLOR == MAGENTA) { HIGHLIGHT = LIGHTMAGENTA; SHADOW = DARKGRAY;}
			if(COLOR == LIGHTGRAY) { HIGHLIGHT = WHITE; SHADOW = DARKGRAY;}
			if(COLOR == DARKGRAY) { HIGHLIGHT = LIGHTGRAY; SHADOW = BLACK; }
			if(COLOR == LIGHTBLUE) { HIGHLIGHT = WHITE; SHADOW = BLUE; }
			if(COLOR == LIGHTGREEN) { HIGHLIGHT = WHITE; SHADOW = GREEN; }
			if(COLOR == LIGHTCYAN) { HIGHLIGHT = WHITE; SHADOW = CYAN; }
			if(COLOR == LIGHTRED) { HIGHLIGHT = WHITE; SHADOW = RED; }
			if(COLOR == LIGHTMAGENTA) { HIGHLIGHT = WHITE; SHADOW = MAGENTA; }
			if(COLOR == YELLOW) { HIGHLIGHT = WHITE; SHADOW = BROWN; }
			if(COLOR == WHITE) { HIGHLIGHT = DARKGRAY; SHADOW = BLACK; }

			}

		// Draw an 'UP' button
		void draw(int offset = 0)
			{

			setlinestyle(SOLID_LINE,0,1);
			setfillstyle(SOLID_FILL,COLOR);
			bar(Xleft, Ytop, Xright, Ybottom);

			if(size > 0)
				{
				setcolor(HIGHLIGHT);
				line(Xleft  , Ytop  , Xright  , Ytop  );
				line(Xleft  , Ytop+1, Xleft  , Ybottom  );
				setcolor(SHADOW);
				line(Xright  , Ytop+1, Xright  , Ybottom  );
				line(Xleft+1, Ybottom  , Xright-1, Ybottom  );
				}
			if(size > 1)
				{
				setcolor(HIGHLIGHT);
				line(Xleft+1, Ytop+1, Xright-1, Ytop+1);
				line(Xleft+1, Ytop+2, Xleft+1, Ybottom-1);
				setcolor(SHADOW);
				line(Xleft+2, Ybottom-1, Xright-2, Ybottom-1);
				line(Xright-1, Ytop+2, Xright-1, Ybottom-1);
				}
			if(size > 2)
				{
				setcolor(HIGHLIGHT);
				line(Xleft+2, Ytop+2, Xright-2, Ytop+2);
				line(Xleft+2, Ytop+3, Xleft+2, Ybottom-2);
				setcolor(SHADOW);
				line(Xright-2, Ytop+3, Xright-2, Ybottom-2);
				line(Xleft+3, Ybottom-2, Xright-3, Ybottom-2);
				}

			if(outline)
				{
				setcolor(BLACK);
				rectangle(Xleft-1,Ytop-1,Xright+1,Ybottom+1);
				}
			settextjustify(CENTER_TEXT, CENTER_TEXT);
			settextstyle(font,HORIZ_DIR,fontsize);

			if(etch)
				{
				setcolor(BLACK);
				outtextxy((Xleft + (Xright-Xleft)/2)+offset,(Ytop + (Ybottom-Ytop)/2)+offset,LABEL);
				setcolor(WHITE);
				outtextxy((Xleft + (Xright-Xleft)/2)+1+offset,(Ytop + (Ybottom-Ytop)/2)+1+offset,LABEL);
				}
			else
				{
				setcolor(BLACK);
				outtextxy((Xleft + (Xright-Xleft)/2)+offset,(Ytop + (Ybottom-Ytop)/2)+offset,LABEL);
				}
			}

		// Draw a 'DOWN' button
		void press(void)
			{

			TEMPCOLOR = HIGHLIGHT;
			HIGHLIGHT = SHADOW;
			SHADOW = TEMPCOLOR;
			if(strcmp(onoffstatus,"ON")==0) strcpy(onoffstatus,"OFF");
			else strcpy(onoffstatus,"ON");
			draw(tempstatus);
			if(tempstatus==1) tempstatus = 0;
			else tempstatus = 1;

			}

		// Draw button temporarily in 'DOWN' position then back 'UP'
		void push(void)
			{

			press();

			TEMPCOLOR = HIGHLIGHT;
			HIGHLIGHT = SHADOW;
			SHADOW = TEMPCOLOR;

			delay(75);
			draw(tempstatus);
			if(tempstatus==1) tempstatus = 0;
			else tempstatus = 1;

			}
		
	};


